@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.7.3+   2012/05/05
+ * Version: 1.7.3+   2015/01/01
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -898,6 +898,8 @@ static int ccs_try_alt_exec(struct ccs_execve_entry *ee)
 	/* Close the requested program's dentry. */
 	ee->obj.path1.dentry = NULL;
 	ee->obj.path1.mnt = NULL;
+	ee->obj.path1_valid = false;
+	ee->obj.path1_parent_valid = false;
 	ee->obj.validate_done = false;
 	allow_write_access(bprm->file);
 	fput(bprm->file);
